package com.emato.cus.supervise.biz;

import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domainOms.OmsMerchInfo;
import com.emato.cus.supervise.domainOms.OmsProductInfo;
import com.emato.cus.supervise.service.oms.OmsDataService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.List;

/**
 *
 * @author zengjunlin
 * @version 1.0
 * 2018-02-02 14:33
 */
@Component
public class OmsDataImpl implements OmsData {

    private static final Logger logger = LoggerFactory.getLogger(OmsDataImpl.class);

    @Autowired
    private OmsDataService omsDataService;
    /**
     * 获取oms 数据
     *
     * @param merchSnList
     * @return
     */
    @Override
    public List getOmsMerchInfoData(List<String> merchSnList) {
        logger.info("---------- 查询Oms商户信息开始 --------------------");

        if (merchSnList == null || merchSnList.isEmpty()) {
            String err = "---商户信息查询为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        List<OmsMerchInfo> resultList = omsDataService.getOmsMerchInfoList(merchSnList);
        if (resultList == null || resultList.size() == 0) {
            String err = "---获取OMS商户数据为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        logger.info("---商户信息查询获数据{}条.", resultList.size());

        logger.info("---------- 查询Oms商户信息结束 --------------------");
        return resultList;
    }
    /**
     * 获取oms 产品数据
     *
     * @param skuList
     * @return
     */
    @Override
    public List getOmsProductData(List<String> skuList) {
        logger.info("---------- 查询Oms产品数据开始 --------------------");

        if (skuList == null || skuList.isEmpty()) {
            String err = "---查询Oms产品数据为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        List<OmsProductInfo> resultList = omsDataService.getOmsProductInfoList(skuList);
        if (resultList == null || resultList.size() == 0) {
            String err = "---获取本次OMS产品数据为空.";
            logger.error(err);
            return Collections.EMPTY_LIST;
        }

        logger.info("---查询Oms产品获取数据{}条.", resultList.size());

        logger.info("---------- 查询Oms产品数据结束 --------------------");
        return resultList;
    }

}
