package com.emato.cus.supervise.biz.acqShelfLoad.up;

import com.emato.cus.supervise.biz.DataConversion;
import com.emato.cus.supervise.constant.Dict;
import com.emato.cus.supervise.domainCus.CusAcqShelfLoad04;
import com.emato.cus.supervise.domainOmsShop.OmsShopAcqShelfLoad;
import com.google.common.collect.Lists;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * 门店入场 即上架 出区
 * @author Scott Chen
 * @version 1.0
 * 2020-03-30 11:27
 */
@Component
public class AcqShelfLoadInUpOmsShopDataConversion implements DataConversion {


    private final static Logger logger = LoggerFactory.getLogger(AcqShelfLoadInUpOmsShopDataConversion.class);

    /**
     * 门店入场 即上架 出区
     *
     * @param params
     * @return
     */
    @Override
    public List conversion(Map params) {
        logger.info("门店入场:上架:开始转换，组装cus数据===========================");

        List<OmsShopAcqShelfLoad> omsShopList = (List<OmsShopAcqShelfLoad>) params.get("omsShopList");

        List<CusAcqShelfLoad04> cusAcqShelfLoad04List = Lists.newArrayList();

        for (int i = 0; i < omsShopList.size(); i++) {
            try {
                OmsShopAcqShelfLoad data = omsShopList.get(i);

                String osku = data.getSkuNo();
                if (StringUtils.isBlank(osku)) {
                    logger.error("当前转换的sku为: {}, 对应的产品备案数据异常", osku);
                    continue;
                }
                //logger.debug("当前转换的sku为: {}", osku);

                CusAcqShelfLoad04 cusAcqShelfLoad04 = new CusAcqShelfLoad04();

                cusAcqShelfLoad04.setGoodsName(data.getGoodsName());
                cusAcqShelfLoad04.setCodeTs(data.getCodeTs());
                cusAcqShelfLoad04.setSkuNo(data.getSkuNo());
                cusAcqShelfLoad04.setGoodsId(data.getGoodsId());

                cusAcqShelfLoad04.setgUnit(data.getgUnit());
                cusAcqShelfLoad04.setgQty(data.getgQty());
                cusAcqShelfLoad04.setLegalUnit(data.getLegalUnit());
                cusAcqShelfLoad04.setLegalQty(data.getLegalQty());

                cusAcqShelfLoad04.setGoodsModel(data.getGoodsModel());
                cusAcqShelfLoad04.setLocalEmsNo(data.getLocalEmsNo());

                cusAcqShelfLoad04.setSeatNo(data.getSeatNo());
                cusAcqShelfLoad04.setShelfLoadTime(data.getShelfLoadTime());
                cusAcqShelfLoad04.setShelfLoadType(data.getShelfLoadType());

                cusAcqShelfLoad04.setStoreCompanyName(Dict.storeCompanyName);
                cusAcqShelfLoad04.setStoreUscCode(Dict.storeUscCode);
                cusAcqShelfLoad04.setStoreCustomsCode(Dict.storeCustomsCode);
                cusAcqShelfLoad04.setStoreCode(Dict.storeCodeMap.get(data.getStoreCode()));

                cusAcqShelfLoad04.setCreateTime(LocalDateTime.now());
                cusAcqShelfLoad04.setCreaterSn(Dict.operater);
                cusAcqShelfLoad04.setModerSn(Dict.operater);
                cusAcqShelfLoad04.setModTime(LocalDateTime.now());

                cusAcqShelfLoad04List.add(cusAcqShelfLoad04);
            }catch (Exception e){
                logger.error("门店入场:上架:开始转换组装cus数据系统异常", e);
            }finally {
                continue;
            }
        }
        logger.info("门店入场:上架:开始转换，组装cus数据结束===========================");
        return cusAcqShelfLoad04List;
    }

}
